@@ -21,7 +21,7 @@ BEGIN
     require Exporter;
     @ISA       = qw( Exporter );
     @EXPORT_OK = qw( api_version );
-    $VERSION   = '0.01_02';
+    $VERSION   = '0.02_01';
 }
 
 *TRUE     = \1;
@@ -40,127 +40,129 @@ my $methods = {};
 my $events = {};
 my $methods_arr = {
     '9.64' => [
-    # Our add-ons
-    qw(
-        processMessages
-    ),
-    # Official API
-    # XXX: API Docs and source code differ (I use the source code names):
-    #           Docs                C++ headers
-    #           -------------------------------------------
-    #           reqIDs()            reqIds()
-    #           setLogLevel()       setServerLogLevel()
-    qw(
-        eConnect
-        eDisconnect
-        isConnected
-        reqCurrentTime
-        serverVersion
-        setServerLogLevel
-        checkMessages
-        TwsConnectionTime
+        # Our add-ons
+        qw(
+            processMessages
+        ),
+        # Official API
+        # XXX: API Docs and source code differ (I use the source code names):
+        #           Docs                C++ headers
+        #           -------------------------------------------
+        #           reqIDs()            reqIds()
+        #           setLogLevel()       setServerLogLevel()
+        qw(
+            eConnect
+            eDisconnect
+            isConnected
+            reqCurrentTime
+            serverVersion
+            setServerLogLevel
+            checkMessages
+            TwsConnectionTime
 
-        reqMktData
-        cancelMktData
-        calculateImpliedVolatility
-        cancelCalculateImpliedVolatility
-        calculateOptionPrice
-        cancelCalculateOptionPrice
+            reqMktData
+            cancelMktData
+            calculateImpliedVolatility
+            cancelCalculateImpliedVolatility
+            calculateOptionPrice
+            cancelCalculateOptionPrice
 
-        placeOrder
-        cancelOrder
-        reqOpenOrders
-        reqAllOpenOrders
-        reqAutoOpenOrders
-        reqIds
-        exerciseOptions
+            placeOrder
+            cancelOrder
+            reqOpenOrders
+            reqAllOpenOrders
+            reqAutoOpenOrders
+            reqIds
+            exerciseOptions
 
-        reqAccountUpdates
+            reqAccountUpdates
 
-        reqExecutions
+            reqExecutions
 
-        reqContractDetails
+            reqContractDetails
 
-        reqMktDepth
-        cancelMktDepth
+            reqMktDepth
+            cancelMktDepth
 
-        reqNewsBulletins
-        cancelNewsBulletins
+            reqNewsBulletins
+            cancelNewsBulletins
 
-        reqManagedAccts
-        requestFA
-        replaceFA
+            reqManagedAccts
+            requestFA
+            replaceFA
 
-        reqHistoricalData
-        cancelHistoricalData
+            reqHistoricalData
+            cancelHistoricalData
 
-        reqScannerParameters
-        reqScannerSubscription
-        cancelScannerSubscription
+            reqScannerParameters
+            reqScannerSubscription
+            cancelScannerSubscription
 
-        reqRealTimeBars
-        cancelRealTimeBars
+            reqRealTimeBars
+            cancelRealTimeBars
 
-        reqFundamentalData
-        cancelFundamentalData
-    ) ],
+            reqFundamentalData
+            cancelFundamentalData
+        ),
+    ],
 };
 my $events_arr = {
     '9.64' => [
-    qw(
-        winError
-        error
-        connectionClosed
-        currentTime
+        qw(
+            winError
+            error
+            connectionClosed
+            currentTime
 
-        tickPrice
-        tickSize
-        tickOptionComputation
-        tickGeneric
-        tickString
-        tickEFP
-        tickSnapshotEnd
+            tickPrice
+            tickSize
+            tickOptionComputation
+            tickGeneric
+            tickString
+            tickEFP
+            tickSnapshotEnd
 
-        orderStatus
-        openOrder
-        nextValidId
+            orderStatus
+            openOrder
+            nextValidId
 
-        updateAccountValue
-        updatePortfolio
-        updateAccountTime
+            updateAccountValue
+            updatePortfolio
+            updateAccountTime
 
-        updateNewsBulletin
+            updateNewsBulletin
 
-        contractDetails
-        contractDetailsEnd
-        bondContractDetails
+            contractDetails
+            contractDetailsEnd
+            bondContractDetails
 
-        execDetails
-        execDetailsEnd
+            execDetails
+            execDetailsEnd
 
-        updateMktDepth
-        updateMktDepthL2
+            updateMktDepth
+            updateMktDepthL2
 
-        managedAccounts
-        receiveFA
+            managedAccounts
+            receiveFA
 
-        historicalData
+            historicalData
 
-        scannerParameters
-        scannerData
-        scannerDataEnd
+            scannerParameters
+            scannerData
+            scannerDataEnd
 
-        realtimeBar
+            realtimeBar
 
-        fundamentalData
+            fundamentalData
 
-        deltaNeutralValidation
-    ),
-    # These are in the headers, but apparently not documented
-    qw(
-        openOrderEnd
-        accountDownloadEnd
-    ) ],
+            deltaNeutralValidation
+        ),
+        # These are in the headers, but apparently not documented
+        qw(
+            openOrderEnd
+            accountDownloadEnd
+        )
+    ],
 };
 
 # Example of adding just a couple of methods for a new version:
@@ -172,11 +174,31 @@ my $events_arr = {
 #    ),
 # };
 
+######################
+# 9.67 methods
+$methods_arr->{'9.67'} = [
+    @{ $methods_arr->{'9.64'} },
+    qw(
+        reqMarketDataType
+    ),
+];
+
+# 9.67 events
+$events_arr->{'9.67'} = [
+    grep { ! /deltaNeutralValidation/ } @{ $events_arr->{'9.64'} },
+    qw(
+        marketDataType
+        commissionReport
+    ),
+];
+
 # Cram them into a hash for O(1) lookup time
-for my $ver ( keys( %$methods_arr ) ) {
+for my $ver ( keys( %$methods_arr ) )
+{
     $methods->{$ver} = { map { $_ => 1 } @{ $methods_arr->{$ver} } };
 }
-for my $ver ( keys( %$events_arr ) ) {
+for my $ver ( keys( %$events_arr ) )
+{
     $events->{$ver}  = { map { $_ => 1 } @{ $events_arr->{$ver} } };
 }
 
@@ -277,6 +299,8 @@ sub is_method
 {
     my( $self, $name ) = ( shift, shift );
 
+    return $FALSE unless( defined( $name ) );
+
     return( exists( $methods->{$self->api_version}->{$name} )
               ? $TRUE
               : $FALSE );
@@ -286,6 +310,8 @@ sub is_event
 {
     my( $self, $name ) = ( shift, shift );
 
+    return $FALSE unless( defined( $name ) );
+
     return( exists( $events->{$self->api_version}->{$name} )
               ? $TRUE
               : $FALSE );
@@ -295,6 +321,8 @@ sub in_api
 {
     my( $self, $name ) = ( shift, shift );
 
+    return $FALSE unless( defined( $name ) );
+
     return( ( $self->is_method( $name ) or $self->is_event( $name ) )
                 ? $TRUE
                 : $FALSE );
@@ -316,7 +344,7 @@ sub api_version
 ###
 
 no warnings 'once';
-*version = *api_version;
+*version  = *api_version;
 *versions = *api_versions;
 
 1;
@@ -370,7 +398,7 @@ Create a new Finance::InteractiveBrokers object.
 
 B<ARGUMENTS:>
 
-B<version =E<gt> $scalar> [ Default: I<9.64> ]
+B<version =E<gt> $scalar> [ Default: C<9.64> ]
 
 The API version you wish to refer to.
 
@@ -382,9 +410,9 @@ B<RETURNS:> blessed C<$object>, or C<undef> on failure.
 
 Initialize the object.  If you are subclassing, override this, not L</new()>.
 
-B<ARGUMENTS:> %HASH of arguments passed into L</new()>
+B<ARGUMENTS:> C<%HASH> of arguments passed into L</new()>
 
-B<RETURNS:> %HASH of any leftover arguments.
+B<RETURNS:> C<%HASH> of any leftover arguments.
 
 =head1 METHODS
 
@@ -394,13 +422,11 @@ B<RETURNS:> %HASH of any leftover arguments.
 
 Get a list of all API versions that can be described by this module.
 
-B<ARGUMENTS:>
+B<ARGUMENTS:> None.
 
-None.
+B<RETURNS:> C<@ARRAY> of API versions.
 
-B<RETURNS:> @ARRAY of all API versions enumerated by this module.
-
-NOTE: B<api_versions()> lso works as a class method, and can be I<optionally> imported via:
+NOTE: C<api_versions()> also works as a class method, and can be I<optionally> imported via:
 
     use Finance::InteractiveBrokers::API qw( api_versions );
 
@@ -416,7 +442,7 @@ Get a list of methods in the constructor-specified version of the API.
 
 B<ARGUMENTS:> None.
 
-B<RETURNS:> @ARRAY of all API method names in this version.
+B<RETURNS:> C<@ARRAY> of all API method names in this version.
 
 =head2 events()
 
@@ -426,7 +452,7 @@ Get a list of events in the constructor-specified version of the API.
 
 B<ARGUMENTS:> None.
 
-B<RETURNS:> @ARRAY of all API events in this version.
+B<RETURNS:> C<@ARRAY> of all API events in this version.
 
 =head2 everything()
 
@@ -436,7 +462,7 @@ Get a list of both methods and events in the constructor-specified version of th
 
 B<ARGUMENTS:> None.
 
-B<RETURNS:> @ARRAY of all API methods and events in this version.
+B<RETURNS:> C<@ARRAY> of all API methods and events in this version.
 
 =head2 is_method()
 
@@ -489,7 +515,7 @@ Get the API version described by this object instance.
 
 B<ARGUMENTS:> None.
 
-B<RETURNS:> The API version as a string (e.g. '9.64').
+B<RETURNS:> The API version as a string (e.g. C<'9.64'>).
 
 =head2 version()
 
